init static method
Initialize (or re-initialize) the meter.
Safe to call multiple times — the new config replaces the old one and the event buffer is reset.
Implementation
static void init(MeterConfig config) => instance._init(config);
Initialize (or re-initialize) the meter.
Safe to call multiple times — the new config replaces the old one and the event buffer is reset.
static void init(MeterConfig config) => instance._init(config);